@@ -724,6 +724,10 @@ GyahtzeeCreateMainWindow (GApplication *app, gpointer user_data)
   GtkWidget *tmp;
   GtkWidget *dicebox;
   GtkWidget *undo_button;
+  GtkWidget *menu_button;
+  GtkWidget *icon;
+  GtkBuilder *builder;
+  GMenuModel *appmenu;
   int i, j;
 
   window = gtk_application_window_new (application);
@@ -738,10 +742,15 @@ GyahtzeeCreateMainWindow (GApplication *app, gpointer user_data)
 		    G_CALLBACK (key_press), NULL);
 
   g_action_map_add_action_entries (G_ACTION_MAP (application), app_entries, G_N_ELEMENTS (app_entries), application);
-  const gchar *vaccels_undo[] = {"<Primary>z", NULL};
-  gtk_application_set_accels_for_action (application, "app.undo", vaccels_undo);
+  const gchar *vaccels_help[] = {"F1", NULL};
+  const gchar *vaccels_new[] = {"<Primary>n", NULL};
   const gchar *vaccels_roll[] = {"<Primary>r", NULL};
+  const gchar *vaccels_undo[] = {"<Primary>z", NULL};
+
+  gtk_application_set_accels_for_action (application, "app.help", vaccels_help);
+  gtk_application_set_accels_for_action (application, "app.new-game", vaccels_new);
   gtk_application_set_accels_for_action (application, "app.roll", vaccels_roll);
+  gtk_application_set_accels_for_action (application, "app.undo", vaccels_undo);
 
   scores_action = g_action_map_lookup_action (G_ACTION_MAP (application), "scores");
   undo_action   = g_action_map_lookup_action (G_ACTION_MAP (application), "undo");
@@ -764,6 +773,16 @@ GyahtzeeCreateMainWindow (GApplication *app, gpointer user_data)
   gtk_widget_show (undo_button);
   gtk_header_bar_pack_start (GTK_HEADER_BAR (hbar), undo_button);
 
+  builder = gtk_builder_new_from_resource ("/org/gnome/tali/ui/menus.ui");
+  appmenu = (GMenuModel *) gtk_builder_get_object (builder, "app-menu");
+
+  menu_button = gtk_menu_button_new();
+  icon = gtk_image_new_from_icon_name ("open-menu-symbolic", GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image (GTK_BUTTON (menu_button), icon);
+  gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (menu_button), appmenu);
+  gtk_widget_show (menu_button);
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (hbar), menu_button);
+
 	/*---- Content ----*/
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
